@@ -12,17 +12,17 @@ try:
     api = api_core.API()
     initialized = api.start_check()
     assert(initialized)
-    print('everything is setup alright!')
 except:
     try:
         import os
-        os.remove(str(Path.home())+'/config.stack')
+        os.remove(path_home+'/.config_stack')
     except:
-        print('no config file')
+        print(f'Stack has not been installed yet!')
+        print(f'setting-up Stack...')
     api = api_core.API()
-    initilized = api.init()
-    
-    if initilized:
+    initialized = api.init()
+
+    if initialized:
         api.start_check()
 
 ### CLI End-points ###
@@ -33,11 +33,15 @@ def init(uri: str):
 
 @app.command("add")
 def add_command(path: str, subpath: str=''):
-    if len(subpath)>1:
-        if subpath[-1] != '/':
-            subpath = subpath + '/'
-    add(api.Initializer,[path],subpath)
-    return True
+        try:
+            if len(subpath)>1:
+                if subpath[-1] != '/':
+                    subpath = subpath + '/'
+            add(api.Initializer,[path],subpath)
+            api.commit('')
+            return True
+        except:
+            return Exception
 
 
 @app.command("remove")
@@ -46,7 +50,7 @@ def remove_command(key: str, subpath: str=''):
         if subpath[-1] != '/':
             subpath = subpath + '/'
     remove(api.Initializer,[key],subpath)
-    return True
+    api.commit('')
 
 # End-points
 @app.command("connect")
@@ -61,7 +65,7 @@ def connect_cli(uri: str):
 
 @app.command("disconnect")
 def disconnect_cli(uri: str):
-    try: 
+    try:
         return {'success': api.disconnectDataset(uri)}
     except:
         return {'success': False}
@@ -71,6 +75,7 @@ def full_remove_key_api(key: str):
     try:
         api_core.remove_full(key)
         print(f"Removed: {key}")
+        api.commit('')
     except:
         print(f"Unable to remove: {key}")
 
@@ -95,8 +100,8 @@ def status_api():
     except:
         return Exception
 
-@app.command("commit")
-def commit_api(comment: str=''):
+@app.command("sync")
+def sync_api(comment: str=''):
     # TODO: do we need to print something?
     return {'success': api.commit(comment)}
 
@@ -114,6 +119,14 @@ def diff_api(v1: str, v0: str, file: str=''):
     return True
 
 
+@app.command("diff_csv")
+def diff_csv(csv1: str, csv2: str):
+    from csv_diff import load_csv, compare
+    diff = compare(load_csv(open(csv1)), load_csv(open(csv2)))
+    print(diff)
+    return True
+
+
 @app.command("revert")
 def revert_api(version):
     assert(version != '')
